@@ -1,4 +1,10 @@
 
+`%NA%` <- function(x, y) {
+  if (is.na(x))
+    y
+  else x
+}
+
 "%ni%" <- Negate("%in%")
 
 # For simulation ----------------------------------------------------------
@@ -16,7 +22,7 @@ get_rng <- function(seed) {
   RNGstate
 }
 
-check_seed <- function() {
+get_global_rng <- function() {
   option_seed <- getOption("exuber.global_seed")
   if (!is.na(option_seed) && !is.null(option_seed)) {
     option_seed
@@ -26,39 +32,54 @@ check_seed <- function() {
 }
 
 set_rng <- function(seed) {
-  rng_state <- get_rng(seed)
-  global_seed <- check_seed()
-  if (!is.null(seed)) {
-    set.seed(seed)
-  } else if (!is.null(global_seed)) {
-    set.seed(global_seed)
+  super <- seed %||% get_global_rng() # local supersedes global
+  rng_state <- super %||% get_rng(seed)
+  if (!is.null(super)) {
+    set.seed(super)
   }
   rng_state
 }
 
+get_rng_state <- function(seed) {
+  seed %||%
+    get_global_rng() %||%
+    get_rng(seed)
+}
+
 # get crit data --------------------------------------------------------
 
 retrieve_crit <- function(x) {
   nr <- NROW(index(x))
-  if (nr > 5 && nr <= length(crit)) {
-    return(get("crit")[[nr]])
-  } else {
-    stop_glue("cannot provide MC critical values see help(crit)")
+  if (nr > 5 && nr <= length(exuber::radf_crit)) {
+    message("Using 'radf_crit' for 'cv'.")
+    return(exuber::radf_crit[[nr]])
+  } else if (nr > length(exuber::radf_crit) && nr <= 2000) {
+    message("Using 'exuberdata::radf_crit2' for 'cv'.")
+    need_exuberdata()
+    return(exuberdata::radf_crit2[[nr]])
+  }else {
+    stop_glue("Cannot provide critical values see help(radf_crit).")
   }
 }
 
 
 # options -----------------------------------------------------------------
 
-set_pb <- function(condition, iter, width = getOption("width") - 10L) {
-  if (condition) {
-    txtProgressBar(min = 1, max = iter - 1, style = 3,
-                   char = "-", width = width)
+show_pb <- function() {
+  isTRUE(getOption("exuber.show_progress")) &&
+    interactive() &&
+    !isTRUE(getOption("rstudio.notebook.executing")) &&
+    !isTRUE(getOption("knitr.in.progress"))
+}
+
+set_pb <- function(iter, width = getOption("width") - 10L) {
+  if (show_pb()) {
+    txtProgressBar(min = 1, max = iter - 1, style = 3, char = "-", width = width)
   }
 }
 
-set_pb_opts <- function(condition, pb) {
-  if (condition) {
+set_pb_opts <- function(pb) {
+  if (show_pb()) {
     list(progress = function(n) setTxtProgressBar(pb, n))
   }else{
     list(progress = NULL)
@@ -68,7 +89,6 @@ set_pb_opts <- function(condition, pb) {
 # tidy --------------------------------------------------------------------
 
 array_to_list <- function(x, var) {
-
   itnames <- pluck(x, var) %>%
     dimnames() %>% pluck(3)
   iter <- length(itnames)
@@ -80,6 +100,7 @@ array_to_list <- function(x, var) {
   out
 }
 
+#' @importFrom tibble add_column
 add_key <- function(x, attr_from) {
   attr_lag <-  get_lag(attr_from) #else 0
   if (is.null(attr_lag)) {
@@ -95,32 +116,17 @@ add_key <- function(x, attr_from) {
   x %>% add_column(key = (nkey + 1):(nrow(.) + nkey))
 }
 
+# predicates --------------------------------------------------------------
 
-# seq ---------------------------------------------------------------------
-
-extract_cv <- function(y, which = "bsadf_cv", lg = 0) {
-
-  if (is_sb(y)) {
-    stop_glue("cannot extract from `sb_cv()`")
-  }
-
-  out <- pluck(y, which)
-  if (lg != 0) {
-    if (is_wb(y)) {
-      out <- out[-c(1:lg), , ]
-    }else{
-      out <- out[-c(1:lg), ]
-    }
-  }
-
-  if (is_wb(y)) {
-    out <- out[, 2, ]
-  }else{
-    out <- out[, 2]
-  }
-
-  out
+#' @importFrom rlang %||%
+is_mc <- function(y) {
+  get_method(y) %||% FALSE == "Monte Carlo"
 }
 
+is_wb <- function(y) {
+  get_method(y) %||% FALSE == "Wild Bootstrap"
+}
 
-
+is_sb <- function(y) {
+  get_method(y) %||% FALSE == "Sieve Bootstrap"
+}
